initialize abstract method

Future<void> initialize()

Initialize the ExecutorchManager

This should be called once before using any other methods. It sets up the platform communication channels and verifies that the ExecuTorch libraries are available.

Implementation

Future<void> initialize();